Pyros-config
===========

.. image:: https://travis-ci.org/asmodehn/pyros-config.svg?branch=master
    :target: https://travis-ci.org/asmodehn/pyros-config

Package to help manage configuration of always running servers
this is heavily inspired from flask configuration

This is a pure python package.
It is also provided as a ROS package for ease of use in pyros

